/*
	Controller para PPU - Versão 1.0.2
	Criado por: Alex Crispim/Web Developer - UNA-SUS/BSB
	Utilizando partes do código de Matheus Tristão
*/
"use strict";
/*Função que inicializa o PPU no projeto e recebe variáveis para o Status padrão do PPU*/
function inicializarPPU(variaveis){
	unasus.pack.initialize();
	var status = unasus.pack.getStatus();
	if(status === undefined){
		status = criarStatusPadrao(variaveis);
	};
	if(status === null){
		return false;
	};
};
/*---------PPU-STATUS--------*/
function criarStatusPadrao(variaveis){
	var status = new Object();
	//Variáveis iniciais do PPU
	status.status = "attended";
	status.percentage = 0;
	status.LTIvalue = 0;
	/**/
	//Variáveis adicionais
	//Código para unir as variáveis padrão e as variáveis recebidas para padronizar usadas no projeto
	//status = Object.assign(status,variaveis);
	/*Código do Object.assign acima com Fix para o IE*/
	var objetos = [status, variaveis],
    resultado =  objetos.reduce(function(r, o){
		Object.keys(o).forEach(function(k){
			r[k] = o[k];
        });
        return r;
	}, {});
	status = resultado;
	/**/
	unasus.pack.setStatus(status);
	return status;
};
/*Função que grava qualquer váriavel status no PPU. Recebe como parâmetros a váriavel registrada e o novo valor a serem gravados. Só é gravado se o valor recebido for diferente do já registrado*/
function gravarStatus(nome, valor){
	var status = unasus.pack.getStatus();
	var tipoStatus = status[nome];
	if(valor !== tipoStatus){
		status[nome] = valor;
		unasus.pack.setStatus(status);
	};
};
/*---------PPU-NAVIGATION--------*/
function criarNavegacaoPadrao(){
	var navegacao = new Object();
	navegacao.previous = "";
	navegacao.current = "";
	return navegacao;
};
/*---------RASTREAR-PPU-NAVIGATION--------*/
function rastrearPagina(){
	var navigation = new Object();
	var url = window.location.href.substr(window.location.href.lastIndexOf("/") + 1);
	var currentNavigation = (url.split('#').length > 1) ? url.split('#')[1] : url.replace(".html", "");
	var oldNavigation = unasus.pack.getPersistence("NAVIGATION");
	if(oldNavigation === undefined){
		oldNavigation = criarNavegacaoPadrao();
	};
	if(oldNavigation === null){
		return false;
	};
	if(currentNavigation !== oldNavigation.current){
		navigation.previous = oldNavigation.current;
		navigation.current = currentNavigation;
		unasus.pack.setPersistence("NAVIGATION", navigation);
	};
};
/*---------PPU-ANSWER--------*/
function armazenarResposta(stage, question, alternative, correct){
	var answer = new Object();
	var arrayQuestions = [{"question": question,"alternative": alternative,"correct": correct}];
	answer.stage = stage;
	answer.questions = arrayQuestions;
	unasus.pack.setPersistence("ANSWER", answer);
};
/*---------PPU-DOWNLOAD--------*/
//Recebe o link completo do arquivo para download, retira sua extensão e nome e as grava na variável DOWNLOAD
function rastrearDownload(linkDownload){
	var download = new Object();
	var currentNavigation = window.location.href.substr(window.location.href.lastIndexOf("/") + 1).replace(".html", "");
	var nomeArquivo = linkDownload.substr(linkDownload.lastIndexOf("/") + 1);
	var extensao = linkDownload.substr(linkDownload.lastIndexOf(".") + 1);
	var tipo = "";
	switch(extensao){
		case "pdf": tipo = "text";
			break;
		case "doc":	tipo = "text";
			break;
		case "docx": tipo = "text";
			break;
		case "mp4":	tipo = "video";
			break;
		case "mp3":	tipo = "audio";
			break;
		case "jpg":	tipo = "image";
			break;
		case "png":	tipo = "image";
			break;
		default: tipo = "other";
	};
	download.current = currentNavigation;
	download.filetype = tipo;
	download.filename = nomeArquivo;
	unasus.pack.setPersistence("DOWNLOAD", download);
};
/*---------PPU-EXTERNAL_LINK--------*/
function rastrearLinkExterno(url){
	var link = new Object();
	var currentNavigation = window.location.href.substr(window.location.href.lastIndexOf("/") + 1).replace(".html", "");
	link.current = currentNavigation;
	link.url = url;
	unasus.pack.setPersistence("EXTERNAL_LINK", link);
};
/*---------PPU-VIDEO--------*/
function configurarQualidadeVideo(resolution){
	//O objeto VIDEO que contém a resolução padrão para os vídeos é carregado
	var oldVideo = unasus.pack.getPersistence("VIDEO");
	//Se oldVideo estiver vazio, significa que ainda não havia nenhuma resolução padrão salva. Por isso é criado um video padrão
	if (oldVideo === undefined){
		oldVideo = criarVideoPadrao();
	};
	if (oldVideo === null){
		return false;
	};
	//Se essa função tiver sido chamada sem o parâmetro resolution significa que não deve ser setado nenhuma nova resolução, mas sim carregada
	if (!resolution){
		return oldVideo.resolution;
	} else {
		//Caso a função tenha o parâmetro resolution, significa que o usuário deseja gravar uma nova resolução
		var video = new Object();
		video.resolution = resolution;
		//A nova resolução recebida na função só é armazenada caso seja diferente da resolução já configurada, para evitar conexões desnecessárias com o servidor
		if (oldVideo.resolution !== video.resolution){
			unasus.pack.setPersistence("VIDEO", video);
		};
	};
};
function criarVideoPadrao(){
	//Aqui é carregado a partir do unasus.pack quais as resoluções disponíveis, definidas no arquivo json
	var resolutions = unasus.pack.getVideoResolutions();
	//Aqui é criado e armazenado um objeto videoDefault, uma vez que não foi encontrado nenhum vídeo armazenado na criação do oldVideo
	var videoDefault = new Object();
	videoDefault.resolution = resolutions[0];
	unasus.pack.setPersistence("VIDEO", videoDefault);
	return videoDefault;
};
/*---------PPU-PERCENTAGE E LTI--------*/
//Função que recebe como parâmetro 1º variável com a instância do pacote unasus.pack, 2º valor da porcentagem a ser atualizada e 3º valor do lti. E retorna a variável do pacote já atualizada.
function atualizarPercentageLTI(status, valorPorcentagem, valorLTI){
	var status_change = false;
	var porcentagem = 0;
	if(valorPorcentagem === 0 && valorLTI === 0){
		return false;
	} else {
		//var status = unasus.pack.getStatus();
		//Aqui atualiza a variável percentage com a regra de deixar sempre o maior valor enviado entre 0 e 100
		porcentagem = parseInt(valorPorcentagem);
		if(porcentagem > status.percentage && porcentagem <= 100){
			status.percentage = porcentagem;
			if(porcentagem > 0 && porcentagem < 100){
				if(status.status !== "attempted"){
					status.status = "attempted";
				};
			};
			if(porcentagem === 100){
				status.status = "completed";
			};
			status_change = true;
		};
		if(porcentagem < 0 || porcentagem > 100){
			console.log("Valor não gravado no PPU. A porcentagem deve estar entre 0 e 100, o valor repassado é " + porcentagem);
		};
		//Aqui atualiza a variável LTI com a regra de deixar sempre o maior valor enviado e possuir 2 casas decimais para o moodle
		if(valorLTI){
			var lti = parseFloat(valorLTI.toFixed(2));
			if(lti > status.LTIvalue && lti <= 1){
				status.LTIvalue = lti;
				status_change = true;
			};
			if(lti < 0 || lti > 1){
				console.log("Valor não gravado no PPU. O valor de LTI deve estar entre 0 e 1, o valor repassado é " + lti);
			};
		};
		if(status_change){
			unasus.pack.setStatus(status);
		};
		return status;
	};
};