/*!
 * jQuery Conversas
 *
 * Copyright 2021–2022, Mateus Moura
 * Dual licensed under the MIT or GPL Version 2 licenses.
 *
 * Versão 1.2
 */


(function( $ ) {
  $.fn.Conversas = function() {
    let ID_FALA = '';
    let ID_PROGRESSO = '';

    function isMobile() {
      const width  = window.innerWidth  || document.body.clientWidth
      const resp = /iPhone|iPad|iPod|Android/i.test(navigator.userAgent) || width <= 768;
      return resp;
    }

    function scrollFala(bloco) {
      const body = $("html, body");
      const gutter = isMobile() ? 10 : 140;
      const blocoHeight = bloco.height() + (isMobile() ? gutter + 170 : gutter);
      const deepHeight = blocoHeight > window.innerHeight ? gutter : window.innerHeight - blocoHeight;

      body.stop().animate({ scrollTop: bloco.offset().top - deepHeight }, 300, 'swing');

      bloco.find('.row:first').animate({
        opacity: 1,
      }, 1500 );
    }

    function atualizarIndice(conversa) {
      const total = $('.bloco-conversas__fala', conversa).length;
      const totalAtivas = $('.bloco-conversas__fala-ativa', conversa).length;

      $('.bloco-atividade__footer-acoes p').text(`(${totalAtivas} de ${total})`);
    }

    function mostrarTodasConversas(conversa) {
      clearTimeout(ID_FALA);
      clearInterval(ID_PROGRESSO);
      $('.bloco-atividade__footer .progress', conversa).hide();

      $('.bloco-conversas__fala:not(".bloco-conversas__fala-ativa")', conversa).addClass('bloco-conversas__fala-ativa').fadeIn().find('.row').animate({
        opacity: 1,
      }, 500);
      $('.btn-iniciar, .btn-mostrarTodos, .btn-retomar, .btn-pause', conversa).hide();
      $('.btn-recomecar', conversa).show();
      if(isMobile()) {
        $('.btn-recomecar', conversa).css('display', 'block')
      }
      $('.btn-anterior', conversa).removeClass('disabled');
      $('.btn-proximo', conversa).addClass('disabled');
      recomecar(conversa);

      atualizarIndice(conversa);
    }

    function proxima(conversa) {
      clearTimeout(ID_FALA);
      clearInterval(ID_PROGRESSO);
      const progresso = $('.bloco-atividade__footer .progress', conversa);
      progresso.find('.progress-bar')[0].style.width = 0;
      const falaAtiva = $('.bloco-conversas__fala-ativa:last', conversa);
      const proximaFala = falaAtiva.next('.bloco-conversas__fala');
      if (proximaFala) {
        proximaFala.fadeIn(function() {
          scrollFala(proximaFala)
        }).addClass('bloco-conversas__fala-ativa');
        $('.btn-anterior', conversa).removeClass('disabled');
        $('.btn-recomecar, .btn-pausar, .btn-retomar', conversa).hide();
        $('.btn-iniciar, .btn-mostrarTodos', conversa).show();

        if (!proximaFala.next('.bloco-conversas__fala').length) {
          recomecar(conversa);
        }

        atualizarIndice(conversa);
      }
    }

    function anterior (conversa) {
      clearTimeout(ID_FALA);
      clearInterval(ID_PROGRESSO);
      const progresso = $('.bloco-atividade__footer .progress', conversa);
      progresso.find('.progress-bar')[0].style.width = 0;
      const falaAtiva = $('.bloco-conversas__fala-ativa:last', conversa);
      const falaAnterior = falaAtiva.prev('.bloco-conversas__fala');

      if (falaAnterior) {
        falaAtiva.removeClass('bloco-conversas__fala-ativa').hide();
        $('.btn-proximo', conversa).removeClass('disabled');
        $('.btn-recomecar, .btn-pausar, .btn-retomar', conversa).hide();
        $('.btn-iniciar, .btn-mostrarTodos', conversa).show();

        scrollFala(falaAnterior);

        if (!falaAnterior.prev('.bloco-conversas__fala').length) {
          $('.btn-anterior', conversa).addClass('disabled');
        }

        atualizarIndice(conversa);
      }
    }

    function recomecar(conversa) {
      $('.btn-pausar, .btn-retomar, .btn-mostrarTodos, .btn-iniciar', conversa).hide();

      $('.btn-proximo', conversa).addClass('disabled');

      $('.bloco-atividade__footer .btn-recomecar', conversa).fadeIn().click(function() {
        $(this).hide();
        $('.bloco-conversas__fala', conversa).removeClass('bloco-conversas__fala-ativa').hide();
        $('.bloco-conversas__fala', conversa).first().addClass('bloco-conversas__fala-ativa').show();
        $('.btn-iniciar, .btn-mostrarTodos', conversa).show();
        $('.btn-proximo', conversa).removeClass('disabled');
        $('.btn-anterior', conversa).addClass('disabled');
        scrollFala($('.bloco-conversas__fala', conversa).first());

        atualizarIndice(conversa);
      });
    }

    function pausar (conversa) {
      clearTimeout(ID_FALA);
      clearInterval(ID_PROGRESSO);
      $('.bloco-atividade__footer .btn-retomar', conversa).fadeIn().on('click', function() {
        $(this).hide();
        iniciar(conversa);
      });

      // Fix para o mobile.
      if(isMobile()) {
        $('.bloco-atividade__footer .btn-retomar', conversa).css('display', 'block')
      }
    }

    function iniciar (conversa) {
      const ativa = $('.bloco-conversas__fala-ativa:last', conversa);

      $('.bloco-atividade__footer .disabled', conversa).removeClass('disabled');
      $('.bloco-atividade__footer .btn-pausar', conversa).fadeIn().on('click', function() {
        $(this).hide();
        pausar(conversa);
      });

      // Fix para o mobile
      if(isMobile()) {
        $('.bloco-atividade__footer .btn-pausar', conversa).css('display', 'block')
      }
      const proximaFala = ativa.next('.bloco-conversas__fala');
      const tempoProximo = proximaFala.next('.bloco-conversas__fala').data('tempo');

      if (!proximaFala) {
        recomecar(conversa);
      }

      proximaFala.fadeIn(function() {
        const $this = $(this);
        $this.addClass('bloco-conversas__fala-ativa');
        const progresso = $('.bloco-atividade__footer .progress', conversa);
        progresso.show();
        let count = 1;

        scrollFala(proximaFala);

        atualizarIndice(conversa);

        clearInterval(ID_PROGRESSO);

        const mostrarProximaFala = function(fala, tempo) {
          clearInterval(ID_PROGRESSO);
          count = 1;
          progresso.find('.progress-bar')[0].style.width = 0;

          ID_FALA = setTimeout(() => {
            fala.fadeIn(function() {
              const proxima = fala.next('.bloco-conversas__fala');
              fala.addClass('bloco-conversas__fala-ativa');

              scrollFala(fala);

              if (proxima.length) {
                mostrarProximaFala(proxima, proxima.data('tempo'))
              } else {
                recomecar(conversa);
              }

              atualizarIndice(conversa);
            })
          }, tempo);

          ID_PROGRESSO = setInterval(() => {
            if (count === 1) {
              progresso.find('.progress-bar')[0].style.width = '1%';
            }
            if (count < 100) {
              progresso.find('.progress-bar')[0].style.width = `${count + 1}%`;
              count+=1;
            }
          }, (tempo - 500) / 100);
        };

        mostrarProximaFala(proximaFala.next('.bloco-conversas__fala'), tempoProximo);
      });
    }

    function configuracoes (conversa) {
      $('.bloco-conversas__fala:first', conversa)
        .addClass('bloco-conversas__fala-ativa')
        .find('.row:first').animate({
          opacity: 1,
        }, 1000 );

      $('.btn-anterior', conversa).on('click', function() {
        anterior(conversa);
      });

      $('.btn-proximo', conversa).on('click', function() {
        proxima(conversa);
      });

      $('.btn-mostrarTodos', conversa).on('click', function() {
        $(this).hide();
        mostrarTodasConversas(conversa);
      });

      $('.btn-iniciar', conversa).on('click', function() {
        $(this).hide();
        iniciar(conversa)
      });
    }

    function init(elem) {
      $.each($(elem), function (index, value) {
        const conversa = $(value);

        configuracoes(conversa);
        atualizarIndice(conversa);
      })
    }

    init(this);

  };
}( jQuery ));
"use strict";

$(document).ready(function () {
  $('.bloco-conversas').Conversas();
});